@@ -56,8 +56,8 @@ def get_funcs(ignore_char: str="_"):
     r = list(globals().items()) + list(locals().items())
     for key, value in r:
         if callable(value) and not re.match(f"^{ignore_char}.*", key):
-            if value.__module__ in [__name__, "__main__"]:
-                funcs.append(value)
+            #if value.__module__ in [__name__, "__main__"]:
+            funcs.append(value)
     return funcs
 
 def clean_args(args: list) -> list:
